Learn R Programming

RichR (version 1.0.0)

Enrichment: Enrichment

Description

Given a list of genes associated to diseases and a background list, it calculates the diseases enrichment. It calculates both pvalues from proportion test and Fisher's exact test. Adjusted BH pvalues are returned.

Usage

Enrichment(Background, Genes2Dis = g2d$clean, Genes)

Arguments

Background

The background list of genes. In generela is the list of genes expressed.

Genes2Dis

A data.frame with the Gene names and the Diseases. The package has two inbuild lists. g2d_clean and g2d_complete. Both lists contains data from 4 publications (GS2D, DisGeNET, Berto2016 and PsyGeNET), however in the clean similar names were treated as the same disease.

Genes

A list of genes to test for enrichment

Value

a list contating the enrichment of diseases

Examples

Run this code
# NOT RUN {
data('g2d')

g2d_clean = g2d$clean

# The user can choose a particular disorder, or use the whole disease set to compare to

g2d_ASD = subset(g2d_clean, g2d_clean$Disease %in% c('AUTISM'))
Enrichment(Background = g2d_clean$Gene.symbol,
Genes2Dis = g2d_ASD,
Genes = g2d_ASD$Gene.symbol[1:100])



# }

Run the code above in your browser using DataLab